@@ -13,7 +13,7 @@ class BlogMixin:
             "page": page_no
 
         }
-        response = requests.post(url, data=data, headers=HEADERS, proxies={"http": proxy})
+        response = requests.post(url, data=data, headers=HEADERS, proxies=proxy)
         response.raise_for_status()
         soup = BeautifulSoup(response.text, 'html.parser')
         blog_tags = soup.find_all("li")
