@@ -9,7 +9,7 @@ class DistrictMixin:
         data = {
             "mode": "district"
         }
-        response = requests.post(url, data=data, headers=HEADERS, proxies={"http": proxy})
+        response = requests.post(url, data=data, headers=HEADERS, proxies=proxy)
         response.raise_for_status()
         themes = response.json()
         themes['_id'] = 1
