@@ -18,30 +18,6 @@ purpose_list = ['아침식사', '점심식사', '저녁식사', '식사모임',
 
 
 class StoreMixin:
-    # def get_stores(self, keyword:str, page_no:int):
-    #
-    #     headers = {
-    #         'user-agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/84.0.4147.135 Safari/537.36',
-    #     }
-    #     data = {
-    #         'type': '',
-    #         'query': keyword,
-    #         'lat': '',
-    #         'lng': '',
-    #         'dis': '',
-    #         'page': str(page_no),
-    #         'chunk': '10',
-    #         'rn': ''
-    #     }
-    #     response = requests.post('https://www.diningcode.com/2018/ajax/list.php', headers=headers, data=data)
-    #     soup = BeautifulSoup(response.text, 'html.parser')
-    #     stores = soup.find_all("a", class_="blink")
-    #     scraped_stores = []
-    #     for store in stores:
-    #         id = store['href'].split('rid=')[-1]
-    #         text = store.text
-    #         scraped_stores.append({"_id": id, "id": id, "text": text})
-    #     return scraped_stores
     def get_stores(self, keyword: str, page_no: int, page_size: int = 20, proxy=None):
 
         headers = {
@@ -71,7 +47,7 @@ class StoreMixin:
                                  headers=headers,
                                  data=data,
                                  allow_redirects=False,
-                                 proxie={"http":proxy})
+                                 proxies=proxy)
         response.raise_for_status()
         response_data = response.json()
         stores = response_data['result_data']['poi_section']['list']
@@ -257,7 +233,7 @@ class StoreMixin:
     def get_banners(self, code: str, proxy:None):
         response = requests.get(f'https://www.diningcode.com/2018/ajax/gallery.php?rid={code}',
                                 headers=HEADERS,
-                                proxies={"http":proxy}
+                                proxies=proxy
                                 )
         soup = BeautifulSoup(response.text, 'html.parser')
         banner_container_tag_soup = soup.find("ul", class_="gallery-thumb-list")
@@ -268,7 +244,7 @@ class StoreMixin:
     def get_store(self, code: str, proxy: None):
         response = requests.post(f'https://www.diningcode.com/profile.php?rid={code}',
                                  headers=HEADERS,
-                                 proxies={"http":proxy}
+                                 proxies=proxy
                                  )
         soup = BeautifulSoup(response.text, 'html.parser')
         store_name = soup.find('div', class_='tit-point').get_text().replace('\n', '')
