@@ -1,33 +1,72 @@
 import re
 from datetime import datetime, timedelta
 
-bracketed_data_pattern = r'(\w+)\((\d+)\)'
+#bracketed_data_pattern = r'(\w+)\((\d+)\)'
+bracketed_data_pattern = r'^(.*?)\((\d+)\)$'
+
+
+
 number_pattern = r'(\d+)'
 
-business_hour_pattern = r'(\w+):\s+(\d{2}:\d{2}) - (\d{2}:\d{2})'
+business_hour_range_pattern = r'(\w+):\s+(\d{2}:\d{2}) - (\d{2}:\d{2})'
 day_pattern = r'(\d+\.\d+) \((\w+)\)'
 blog_id_pattern = r'\?bid=([a-fA-F0-9]+)'
 days_ago_pattern = r'(\d+)일전'
 width_percentage_pattern = r'width:(\d+)%;'
 background_image_url_pattern = r"url\(['\"](https?://[^)]+)['\"]\)"
 
-special_business_hour_pattern = '^[^:]+: \d{2}:\d{2}$'
-special_business_hour_parsing_pattern = r'^([^:]+): (\d{2}:\d{2} - \d{2}:\d{2})$'
+special_business_hour_range_pattern = r'^(.*?): (\d{2}:\d{2}) - (\d{2}:\d{2})$'
+special_business_hour_parsing_range_pattern = r'^(.*?): (\d{2}:\d{2}) - (\d{2}:\d{2})$'
 
+special_business_hour_single_pattern = r'^(.*?): (\d{2}:\d{2})$'
+special_business_hour_parsing_single_pattern = r'^(.*?): (\d{2}:\d{2})$'
+
+special_day_without_time_pattern = r'^[^0-9:-]+$'
+
+def is_special_day_without_time_pattern(text):
+    match = get_match_for_pattern(text, special_day_without_time_pattern)
+    if match:
+        return True
+    else:
+        return False
+
+def parse_special_day_without_time_pattern(text):
+    match = get_match_for_pattern(text, special_day_without_time_pattern)
+
+    return match
+
+def is_single_special_business_hour(text):
+    # 정규표현식으로 패턴 확인
+    if re.search(special_business_hour_single_pattern, text):
+        return True
+    else:
+        return False
+
+
+def parse_single_special_business_hour(text):
+    # 정규표현식으로 패턴 확인
+    match = get_match_for_pattern(text, special_business_hour_parsing_single_pattern)
+    if not match:
+        return None
+    return {
+        "type":match.group(1),
+        "time": match.group(2)
+    }
 
 def parse_special_business_hour(text):
-    match = re.search(special_business_hour_parsing_pattern, text)
+    match = re.search(special_business_hour_parsing_range_pattern, text)
     if match:
-        type = match.group(0)
-        time = match.group(1)
-        return {"type": type, "time": time}
+        type = match.group(1)
+        start_time = match.group(2)
+        end_time = match.group(2)
+        return {"type": type, "start_time": start_time, "end_time":end_time}
     else:
         return None  # 매칭되는 패턴이 없을 경우 None 반환
 
 
 def is_special_business_hour(text):
     # 정규표현식으로 패턴 확인
-    if re.search(special_business_hour_pattern, text):
+    if re.search(special_business_hour_range_pattern, text):
         return True
     else:
         return False
@@ -118,7 +157,7 @@ def parse_number(text: str):
 
 
 def parse_business_hour_pattern(text):
-    match = get_match_for_pattern(text, business_hour_pattern)
+    match = get_match_for_pattern(text, business_hour_range_pattern)
     type = match.group(1)
     start_time = match.group(2)
     end_time = match.group(3)
@@ -129,6 +168,13 @@ def parse_business_hour_pattern(text):
     }
 
 
+def is_date_and_day_of_the_week_pattern(text):
+    match = get_match_for_pattern(text, day_pattern)
+    if match:
+        return True
+    else:
+        return False
+
 def parse_date_and_day_of_the_week_pattern(text):
     match = get_match_for_pattern(text, day_pattern)
     date = match.group(1)
